from typing import Any

from formee.auth.user_jwt import get_user_jwt
from formee.formTools.read import read_form
from gql import Client, gql
from gql.transport.aiohttp import AIOHTTPTransport
from rich import print

transport = AIOHTTPTransport(url="https://hrbt-portal.hasura.app/v1/graphql",
                             headers={'Authorization': 'Bearer ' + get_user_jwt()})

# Create a GraphQL client using the defined transport
client = Client(transport=transport, fetch_schema_from_transport=True)

initial_form_creation_query = gql("""
mutation CreateForm($description: String!, $title: String!) {
  insert_Form_one(object: {title: $title, description: $description}) {
    id
    description
    title
  }
}
""")

add_confirm_ques = gql("""
mutation AddConfirmQues($title: String!, $form: Int!) {
  insert_ques_confirm(objects: {title: $title, form: $form}) {
    returning {
      form
      id
      title
    }
  }
}
""")

add_number_ques = gql("""
mutation AddNumberQues($title: String!, $form: Int!) {
  insert_ques_number(objects: {title: $title, form: $form}) {
    returning {
      form
      id
      title
    }
  }
}
""")

add_options_ques = gql("""
mutation AddOptionsQues($form: Int!, $title: String!) {
  insert_ques_options(objects: {form: $form, title: $title}) {
    returning {
      form
      id
      title
    }
  }
}
""")

add_text_ques = gql("""
mutation AddTextQues($form: Int!, $title: String!) {
  insert_ques_text(objects: {form: $form, title: $title}) {
    returning {
      form
      title
      id
    }
  }
}
""")

add_choices = gql("""
mutation AddChoices($question: uuid!, $title: String!) {
  insert_option(objects: {title: $title, question: $question}) {
    returning {
      id
      question
      title
    }
  }
}
""")


def deploy() -> Any:
    """
    Returns:
        Any: None if unsuccessful, else the form id
    """
    form_data = read_form()
    if form_data is None:
        print("[red]No form found. Exiting.")
        return
    print(form_data)
    retured_form_id = client.execute(initial_form_creation_query, variable_values={
        'title': form_data['name'], 'description': form_data['description']})['insert_Form_one']['id']

    for question in form_data['questions']:
        if question['type'] == 'Text' or question['type'] == 'Short Text':
            client.execute(add_text_ques, variable_values={
                           'form': retured_form_id, 'title': question['question']})
        elif question['type'] == 'Options':
            ques_id = client.execute(add_options_ques, variable_values={
                'form': retured_form_id, 'title': question['question']})
            for choice in question['options']:
                client.execute(add_choices, variable_values={
                               'question': ques_id['insert_ques_options']['returning'][0]['id'], 'title': choice})
        elif question['type'] == 'Number':
            client.execute(add_number_ques, variable_values={
                           'form': retured_form_id, 'title': question['question']})
        elif question['type'] == 'Confirm':
            client.execute(add_confirm_ques, variable_values={
                           'form': retured_form_id, 'title': question['question']})
        else:
            print("[red]Invalid question type.")
            return
    print("[green]Form deployed successfully.")
    print("[green]Form ID: " + str(retured_form_id))
    print("[green]Form URL: https://formee.hackersreboot.tech/form/" + str(retured_form_id))
    return retured_form_id



import os

import requests
import yaml
from formee.auth.hasher import hash_password
from formee.auth.login import DEST_PATH
from formee.auth.visitor_jwt import get_visitor_jwt
from PyInquirer import prompt
from rich import print


def registerPrompt() -> None:
    """
    """
    questions = [
        {
            'type': 'input',
            'name': 'username',
            'message': 'Enter your username:',
            'validate': lambda val: val != ''
        },
        {
            'type': 'password',
            'name': 'password',
            'message': 'Enter your password:',
            'validate': lambda val: val != '',
            'filter': lambda val: hash_password(val)
        },
    ]
    answers = prompt(questions)
    usr_registered = register(answers['username'], answers['password'])
    if usr_registered:
        print(f"[green]User {answers['username']} registered successfully.")
    else:
        print(
            f"[red]User {answers['username']} not registered. Try new username.")
        registerPrompt()


def register(username: str, password: str) -> bool:
    """

    Args:
        username (str): Username of the user to be registered
        password (str): Password of the user to be registered

    Returns:
        bool: True when registration is successful
    """
    url = 'https://hrbt-portal.hasura.app/api/rest/createUser'
    headers = {'Content-Type': 'application/json',
               'Authorization': 'Bearer ' + get_visitor_jwt()}
    body = {'username': username, 'password': password}
    response = requests.post(url, headers=headers, json=body)
    if response.status_code == 200:
        yaml.dump({'username': username, 'password': password, 'visitor': False},
                  open(DEST_PATH, 'w'))

    return response.status_code == 200



import requests
from formee.auth.check import check_login


def get_user_jwt() -> str:
    """
    Returns:
        str: The JWT token of the user
    """
    login_data = check_login()
    if not login_data:
        token = requests.get(
            'https://formee-auth.hackersreboot.tech/visitor').json()['token']
        return token

    if login_data:
        token = requests.get('https://formee-auth.hackersreboot.tech/', json={
                             'username': login_data['username'], 'password': login_data['password']}).json()['token']
        return token



import sys

# Importing third party modules
from pyfiglet import Figlet
from PyInquirer import Separator, prompt
from rich import print

from formee.auth.check import check_login
from formee.auth.login import login
from formee.auth.register import registerPrompt
from formee.auth.visitor_settings import load_visitor_settings


def main() -> None:
    # Loading the title
    title = Figlet(font='avatar')
    print(f"[red]{title.renderText('Formee')}")
    if not check_login():
        register_or_login = prompt([
            {
                'type': 'list',
                'name': 'register_or_login',
                'message': 'What do you want to do?',
                'choices': ['Register', 'Login', 'I\'m just visiting', Separator(), 'Exit']
            }
        ])
        if register_or_login['register_or_login'] == 'Register':
            registerPrompt()
        elif register_or_login['register_or_login'] == 'Login':
            login()
        elif register_or_login['register_or_login'] == 'I\'m just visiting':
            load_visitor_settings()
        elif register_or_login['register_or_login'] == 'Exit':
            sys.exit()

    usr_data = check_login()
    if usr_data is None:
        print(f"[green]Hi Visitor!")
    else:
        print("[blue] Welcome to Formee! Logged in as [bold]{}".format(
            usr_data['username']))
    # Loading the questions
    action = [
        {
            'type': 'list',
            'name': 'action',
            'message': 'What do you want to do?',
            'choices': [
                Separator('= Create ='),
                {
                    'name': 'Create a new form'
                },
                Separator('= View Form Data ='),
                {
                    'name': 'View a form file\'s data'
                },
                Separator('= Try a form ='),
                {
                    'name': 'Try a form from a file'
                },
                Separator('= Fill a form ='),
                {
                    'name': 'Fill a form from an ID'
                },
                Separator('= Deploy a form ='),
                {
                    'name': 'Deploy a form'
                },
                Separator('= View Responses ='),
                {
                    'name': 'View responses from a form'
                },
                Separator('= Exit ='),
                {
                    'name': 'Exit'
                },
            ]
        }
    ]
    # Asking the questions
    answers = prompt(action)
    # Checking the answers
    if answers['action'] == 'Exit':
        sys.exit(1)
    elif answers['action'] == 'Create a new form':
        from formee.formTools.create import create_form
        create_form()
        sys.exit(0)
    elif answers['action'] == 'View a form file\'s data':
        from formee.formTools.read import display_form_data
        display_form_data()
        sys.exit(0)
    elif answers['action'] == 'Try a form from a file':
        from formee.formTools.read import try_form
        try_form()
        sys.exit(0)
    elif answers['action'] == 'Deploy a form':
        if usr_data:
            from formee.formTools.deploy import deploy
            deploy()
            sys.exit(0)
        else:
            print("[red]You must be logged in to deploy a form.")
            sys.exit(1)
    elif answers['action'] == 'Fill a form from an ID':
        from formee.formTools.fill import fill_prompt
        fill_prompt()
        sys.exit(0)
    elif answers['action'] == 'View responses from a form':
        from formee.formTools.responses import get_responses
        get_responses()
        sys.exit(0)


if __name__ == '__main__':
    main()



import requests


def get_visitor_jwt() -> str:
    """

    Returns:
        str: The JWT token for a visitor
    """
    token = requests.get(
        'https://formee-auth.hackersreboot.tech/visitor').json()['token']
    return token



from typing import Any

import requests
from formee.auth.visitor_jwt import get_visitor_jwt


def validate_user(username: str, password: str) -> Any:
    """
    Args:
        username (str): Username of the user to be validated
        password (str): Password of the user to be validated

    Returns:
        Any: False when user is not validated, else the user data
    """
    url = 'https://hrbt-portal.hasura.app/api/rest/user/'
    headers = {'Content-Type': 'application/json',
               'Authorization': 'Bearer ' + get_visitor_jwt()}
    body = {'username': username, 'password': password}
    response = requests.get(url, headers=headers, json=body).json()
    if len(response['User']) == 0:
        return False
    return response['User'][0]



import hashlib


def hash_password(password: str) -> str:
    """
    Args:
        password (str): The password to be hashed

    Returns:
        str: Hashed password
    """
    return hashlib.sha256(password.encode('utf-8')).hexdigest()



from PyInquirer import ValidationError, Validator


class NumberValidator(Validator):
    def validate(self, document: str) -> None:
        try:
            int(document.text)
        except ValueError:
            raise ValidationError(
                message='Please enter a number',
                cursor_position=len(document.text))



import os

import yaml
from formee.auth.hasher import hash_password
from formee.auth.validate import validate_user
from PyInquirer import prompt
from rich import print

DEST_DIR = os.path.expanduser('~')
DEST_PATH = os.path.join(DEST_DIR, '.formee.yml')


def login() -> bool:
    """
    Returns:
        bool: True when login is successful
    """
    questions = [
        {
            'type': 'input',
            'name': 'username',
            'message': 'Enter your username:',
            'validate': lambda val: val != ''
        },
        {
            'type': 'password',
            'name': 'password',
            'message': 'Enter your password:',
            'validate': lambda val: val != '',
            'filter': lambda val: hash_password(val)
        },
    ]
    answers = prompt(questions)
    usr_logged_in = validate_user(
        answers['username'], answers['password'])

    if not usr_logged_in:
        print(
            f"[red]User {answers['username']} not logged in. Try new username.")
        login()

    else:
        yaml.dump({'username': answers['username'], 'password': answers['password'], 'visitor': False},
                  open(DEST_PATH, 'w'))
        print(
            f"[green]User {answers['username']} logged in successfully.")
        return True



import yaml
from PyInquirer import prompt
from rich import print


def create_form() -> None:
    initial_details = prompt([
        {
            'type': 'input',
            'name': 'name',
            'message': 'Enter the name of the form:',
            'validate': lambda val: val != '' and len(val) <= 20
        },
        {
            'type': 'input',
            'name': 'description',
            'message': 'Enter the description of the form:',
            'validate': lambda val: val != '' and len(val) <= 1000
        }
    ])
    questions = create_questions()
    form = {
        'name': initial_details['name'],
        'description': initial_details['description'],
        'gen_detail': 'formee_beta',
        'questions': questions
    }
    yaml.dump(form, open(initial_details['name'].lower(
    ).strip().replace(' ', '-') + '.yaml', 'w'))
    print(f"[green]Form created successfully.")


def create_questions() -> list:
    """
    Returns:
        list: Questions to be asked in the form
    """
    questions = []
    question_prompt = [
        {
            'type': 'input',
            'name': 'question',
            'message': 'Enter the question:',
            'validate': lambda val: val != '' and len(val) <= 100
        },
        {
            'type': 'list',
            'name': 'type',
            'message': 'Enter the type of the question:',
            'choices': ['Text', 'Number', 'Confirm', 'Options']
        },
        {
            'type': 'confirm',
            'name': 'required',
            'message': 'Is this question required?',
            'default': True
        }
    ]

    while True:
        question = prompt(question_prompt)
        if question['type'] == 'Options':
            question['options'] = prompt([
                {
                    'type': 'input',
                    'name': 'options',
                    'message': 'Enter the options [Seperate using *;*]:',
                    'validate': lambda val: val != '' and len(val) <= 1000,
                    'filter': lambda val: list(map(lambda x: x.strip(), val.split(';')))
                }
            ])['options']
        questions.append(question)
        confirmation = prompt([
            {
                'type': 'confirm',
                'name': 'continue',
                'message': 'Do you want to add more questions?'
            }
        ])
        if not confirmation['continue']:
            break

    return questions



import yaml
from formee.formTools.validators import NumberValidator
from PyInquirer import prompt
from rich import print
from yaml.parser import ParserError


def read_form() -> dict:
    """
    Returns:
        dict: The data of the form
    """
    form_path = prompt([
        {
            'type': 'input',
            'name': 'form_path',
            'message': 'Enter the path to the form:',
            'validate': lambda val: val != '' and len(val) <= 200
        }
    ])
    form = read_form_file(form_path['form_path'])
    if form == 'Invalid YAML file':
        print(f"[red]It is not a valid YAML File.")
        read_form()
    elif form == 'File not found':
        print(f"[red]File not found.")
        read_form()
    elif form == 'Invalid content in YAML file':
        print(f"[red]Invalid content in YAML file.")
        read_form()
    return form


def display_form_data() -> None:
    form = read_form()
    print(f"\n[bold]Name: {form['name']}")
    print(f"Description: {form['description']}")
    print(f"Generated by: {form['gen_detail']}")
    print(f"\n[bold]Questions:")
    for question in form['questions']:
        print(f"\n[bold]Question: {question['question']}")
        print(f"Type: {question['type']}")
        if question['type'] == 'Options':
            print(f"Options: {question['options']}")
        print(f"Required: {question['required']}")


def read_form_file(form_path: str) -> dict:
    """
    Args:
        form_path (str): The path to the form file
    Returns:
        dict: The data of the form
    """
    try:
        form = yaml.safe_load(open(form_path, 'r'))
        try:
            form['name']
            form['description']
            form['questions']
            form['gen_detail']
        except KeyError:
            return 'Invalid content in YAML file'
    except ParserError:
        return 'Invalid YAML file'
    except FileNotFoundError:
        return 'File not found'
    return form


def try_form() -> None:
    """
    """
    form = read_form()
    form_data = {}

    for question in form['questions']:
        if question['type'] == 'Text':
            form_data[question['question']] = prompt([
                {
                    'type': 'input',
                    'name': question['question'],
                    'message': question['question'],
                    'validate': lambda val: val != '' and len(val) <= 100
                }
            ])
        elif question['type'] == 'Short Text':
            form_data[question['question']] = prompt([
                {
                    'type': 'input',
                    'name': question['question'],
                    'message': question['question'],
                    'validate': lambda val: val != '' and len(val) <= 20
                }
            ])
        elif question['type'] == 'Number':
            form_data[question['question']] = prompt([
                {
                    'type': 'input',
                    'name': question['question'],
                    'message': question['question'],
                    'validate': NumberValidator
                }
            ])
        elif question['type'] == 'Confirm':
            form_data[question['question']] = prompt([
                {
                    'type': 'confirm',
                    'name': question['question'],
                    'message': question['question'],
                    'default': False
                }
            ])
        elif question['type'] == 'Email':
            form_data[question['question']] = prompt([
                {
                    'type': 'input',
                    'name': question['question'],
                    'message': question['question'],
                    'validate': lambda val: val != '' and len(val) <= 100
                }
            ])
        elif question['type'] == 'Options':
            form_data[question['question']] = prompt([
                {
                    'type': 'list',
                    'name': question['question'],
                    'message': question['question'],
                    'choices': question['options']
                }
            ])



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['formee', 'formee.auth', 'formee.formTools']

package_data = \
{'': ['*']}

install_requires = \
['PyInquirer>=1.0.3,<2.0.0',
 'PyYAML>=6.0,<7.0',
 'aiohttp>=3.8.1,<4.0.0',
 'gql>=3.1.0,<4.0.0',
 'pyfiglet>=0.8.post1,<0.9',
 'python-dotenv>=0.20.0,<0.21.0',
 'requests>=2.27.1,<3.0.0',
 'rich>=12.0.1,<13.0.0']

entry_points = \
{'console_scripts': ['formee = formee.__main__:main']}

setup_kwargs = {
    'name': 'formee',
    'version': '0.1.5',
    'description': 'Formee is a tool that provides an easy way to create, edit and manage all of your forms from the command line. It uses a powerful GraphQL API and strives to make the process of working with forms as easy and simple as possible.',
    'long_description': "\n# Formee- The terminal forms\n\nFormee is a tool that provides an easy way to create, edit and manage all of your forms from the command line. It uses a powerful GraphQL API and strives to make the process of working with forms as easy and simple as possible.\n\n![Formee Logo](docs/docs_assets/images/logo.svg)\n\n\n## Badges\n\n[![MIT License](https://img.shields.io/apm/l/atomic-design-ui.svg?)](https://github.com/Arpan-206https://docs.formee.hackersreboot.tech/learn/01-getting%20started/formee/blob/main/LICENSE)\n[![Python 3.8 or above](https://img.shields.io/badge/python-%5E3.8-blue)](https://python.org/)\n[![Hasura](https://img.shields.io/badge/Built%20With-Hasura-yellowgreen)](https://hasura.io)\n\n\n## Installation\n\n1. Install *formee* with pip\n\n```bash\npip3 install formee\n```\n\n2. Use the Github repository\n\n    ```bash\n    git clone https://github.com/Arpan-206/formee.git\n    cd formee\n    ```\n\n    - If you use poetry, then:\n        ```bash\n        poetry install\n        ```\n    - Otherwise, use pip\n        ```bash\n        pip3 install -r requirements.txt\n        ```\n\n## Usage\n\n1. [Install the CLI.](#Installation)\n2. Run the command\n```bash\npython3 -m formee\n```\nOr just\n```bash\nformee\n```\n3. You're good to go.\n\n## Learn\nIf you want to learn how to use Formee, then you can visit [the learn segment in the docs](https://docs.formee.hackersreboot.tech/learn/01-getting%20started).\n## Documentation\nAccess the Documentation over \n[here](https://docs.formee.hackersreboot.tech/).\n\n\n## License\n\n[MIT](https://github.com/Arpan-206/formee/blob/main/LICENSE)\n\n\n\n## Roadmap\n\n- Add more type of fields\n- Work on security\n- Work on Auth\n- Improve WebUI\n- Improve runtime\n\n\n## Authors\n- [@Arpan-206](https://github.com/Arpan-206)\n\n\n## Feedback\nIf you have any feedback, please reach out to us at arpan@hackersreboot.tech.\n\n\n## Contributing\nContributions are always welcome!\nSee `contributing.md` for ways to get started.\nPlease adhere to this project's `code of conduct`.",
    'author': 'Arpan Pandey',
    'author_email': 'arpan@hackersreboot.tech',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/Arpan-206/formee',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)



import json
from formee.auth.check import check_login
from formee.formTools.fill import get_form_details
from gql import Client, gql
from gql.transport.aiohttp import AIOHTTPTransport
from PyInquirer import prompt
from rich import print
from formee.auth.user_jwt import get_user_jwt
from rich.table import Table
import yaml
get_answers_query = gql("""
query GetAnswers($_eq: Int = 16) {
  answers(where: {Form: {id: {_eq: $_eq}}}) {
    data
    filled_by
    form
    form_creator
    id
  }
}
""")


def get_responses() -> None:
    user_data = check_login()
    if not user_data:
        print("[red]You must be logged in to view responses.")
        return
    transport = AIOHTTPTransport(url="https://hrbt-portal.hasura.app/v1/graphql",
                                 headers={'Authorization': 'Bearer ' + get_user_jwt()})

    # Create a GraphQL client using the defined transport
    client = Client(transport=transport, fetch_schema_from_transport=True)
    form_id = prompt([{
        'type': 'input',
        'name': 'form_id',
        'message': 'Enter the form id:',
        'validate': lambda val: val != ''
    }])['form_id']

    form_details = get_form_details(form_id)

    if not form_details:
        print(f"[red]Form with id {form_id} not found.")
        get_responses()

    if user_data['username'] == form_details['User']['username']:
        print(f"[green]Loading response to {form_details['title']}")
        form_responses = client.execute(
            get_answers_query, variable_values={'_eq': form_id})['answers']

        mode_of_display = prompt([{
            'type': 'list',
            'name': 'mode',
            'message': 'Select the mode of display:',
            'choices': ['Table', 'JSON', 'Write to JSON file', 'Write to YAML file', 'Cancel']
        }])['mode']

        if mode_of_display == 'Table':
            table = Table(title=f"{form_details['title']}")
            table.add_column('ID', style='green')
            table.add_column('Filled By', style='green')
            table.add_column('Form', style='green')
            table.add_column('Form Creator', style='green')
            table.add_column('Data', style='green')
            for response in form_responses:
                table.add_row(str(response['id']), response['filled_by'],
                              str(response['form']), response['form_creator'], str(response['data']))
            print(table)
        elif mode_of_display == 'JSON':
            print(json.dumps(form_responses, indent=4))
        elif mode_of_display == 'Write to JSON file':
            file_name = prompt([{
                'type': 'input',
                'name': 'file_name',
                'message': 'Enter the file name:',
                'validate': lambda val: val != ''
            }])['file_name']
            with open(file_name, 'w') as file:
                file.write(json.dumps(form_responses, indent=4))
                print(f"[green]Successfully wrote to {file_name}")
        elif mode_of_display == 'Write to YAML file':
            file_name = prompt([{
                'type': 'input',
                'name': 'file_name',
                'message': 'Enter the file name:',
                'validate': lambda val: val != ''
            }])['file_name']
            with open(file_name, 'w') as file:
                file.write(yaml.dump(form_responses, default_flow_style=False))
                print(f"[green]Successfully wrote to {file_name}")
        else:
            print("[red]Cancelled.")

    else:
        print(f"[red]You can only view responses to your own forms.")
        get_responses()

    return


import os
from typing import Any

import yaml
from formee.auth.login import DEST_PATH
from formee.auth.validate import validate_user


def check_login() -> Any:
    """
    Args:
        None
    Returns:
        Any: Depends on the login status
    """
    if (os.path.isfile(DEST_PATH)):
        login_data = yaml.safe_load(open(DEST_PATH, 'r'))
        if login_data['visitor']:
            return None
        return validate_user(login_data['username'], login_data['password'])

    return False



import json

from formee.auth.check import check_login
from formee.auth.user_jwt import get_user_jwt
from formee.formTools.validators import NumberValidator
from gql import Client, gql
from gql.transport.aiohttp import AIOHTTPTransport
from PyInquirer import prompt
from rich import print

transport = AIOHTTPTransport(url="https://hrbt-portal.hasura.app/v1/graphql",
                             headers={'Authorization': 'Bearer ' + get_user_jwt()})

# Create a GraphQL client using the defined transport
client = Client(transport=transport, fetch_schema_from_transport=True)

get_form_details_query = gql("""
query GetForm($id: Int!) {
  Form_by_pk(id: $id) {
    User {
      username
    }
    id
    description
    title
    ques_confirms {
      title
    }
    ques_numbers {
      title
    }
    ques_options {
      title
      options {
        title
      }
    }
    ques_texts {
      title
    }
  }
}
""")

answer_mutation = gql("""
mutation AnswerForm($data: json!, $filled_by: String!, $form: Int!, $form_creator: String!) {
  insert_answers_one(object: {filled_by: $filled_by, data: $data, form: $form, form_creator: $form_creator}) {
    filled_by
    form
    form_creator
    id
  }
}
""")


def get_form_details(id: int) -> dict:
    """
    Args:
        id (int): ID of the form to be fetched

    Returns:
        dict: Data of the form
    """
    return client.execute(get_form_details_query, variable_values={"id": id})['Form_by_pk']


def fill_prompt() -> dict:
    """
    Returns:
        dict: Data of the form
    """
    questions = [
        {
            'type': 'input',
            'name': 'form_id',
            'message': 'Enter the form id:',
            'validate': lambda val: val != ''
        },
    ]
    answers = prompt(questions)
    form_details = get_form_details(answers['form_id'])
    if not form_details:
        print(f"[red]Form with id {answers['form_id']} not found.")
        fill_prompt()
    print("\n")
    print(f"[blue] Filling form {form_details['title']}")
    print(f"[yellow] Created by {form_details['User']['username']}")
    print(f"[green] Description: {form_details['description']}")

    ques_answers = {}
    for ques in form_details['ques_texts']:
        ques_answers[ques['title']] = prompt([{
            'type': 'input',
            'name': ques['title'],
            'message': ques['title'],
            'validate': lambda val: val != '' and len(val) <= 1000
        }])[ques['title']]
    for ques in form_details['ques_numbers']:
        ques_answers[ques['title']] = prompt([{
            'type': 'input',
            'name': ques['title'],
            'message': ques['title'],
            'validate': NumberValidator
        }])[ques['title']]
    for ques in form_details['ques_options']:
        ques_answers[ques['title']] = prompt([{
            'type': 'list',
            'name': ques['title'],
            'message': ques['title'],
            'choices':  [opt['title'] for opt in ques['options']]
        }])[ques['title']]
    for ques in form_details['ques_confirms']:
        ques_answers[ques['title']] = prompt([{
            'type': 'confirm',
            'name': ques['title'],
            'message': ques['title']
        }])[ques['title']]

    print("\n")
    usr_data = check_login()

    if usr_data is None:
        usrname = 'Anonymous'
    else:
        usrname = usr_data['username']
    answer_return = client.execute(answer_mutation, variable_values={"data": json.dumps(
        ques_answers), "form": form_details['id'], "filled_by": usrname, "form_creator": form_details['User']['username']})['insert_answers_one']
    print(f"[green] Form filled successfully.")
    print(f"[green] Response id: {answer_return['id']}")
    print(f"[green] Filled by: {answer_return['filled_by']}")
    print(f"[green] Form creator: {answer_return['form_creator']}")
    print(f"[green] Form id: {answer_return['form']}")
    return answer_return
